/*
    Game Genie Decoder Program v 3.2
    Copyright (C) 2001 John David Ratliff
    Questions or Comments: 
    	E-Mail: jdratlif@cs.indiana.edu
    	URL:	http://www.technoplaza.net    
    
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

// C Header File
// Created 5/27/01; 8:24:02 PM

#ifndef _GGDECODE_H
#define _GGDECODE_H

/* System Support. Comment out one or more of these lines
	to customize the program for the kinds of game
	genie codes you want to convert. */

#define _NES_SUPPORT_
#define _SNES_SUPPORT_
#define _GENESIS_SUPPORT_
#define _GBGG_SUPPORT_

/* Both of these CANNOT be defined simultaneously! Compile One
   Version or the other, NOT both! The program will almost
   certainly crash if you use both! */

#define _TI89_
// #define _TI92_

#ifdef _TI89_
#define MAIN_WIDTH	120
#define	MAIN_HEIGHT	50
#define COPY_WIDTH	140
#define COPY_HEIGHT	60
#define NES_WIDTH	125
#define NES_HEIGHT	75
#define SNES_WIDTH	125
#define SNES_HEIGHT	55
#define GENESIS_WIDTH	125
#define GENESIS_HEIGHT	50
#define GBGG_WIDTH	130
#define GBGG_HEIGHT	55
#endif

#ifdef _TI92_
#define	MAIN_WIDTH	180
#define	MAIN_HEIGHT	55
#define COPY_WIDTH	235
#define COPY_HEIGHT	65
#define NES_WIDTH	165
#define NES_HEIGHT	85
#define SNES_WIDTH	205
#define SNES_HEIGHT	65
#define GENESIS_WIDTH	200
#define GENESIS_HEIGHT	55
#define GBGG_WIDTH	195
#define GBGG_HEIGHT	65
#endif

enum SystemTypes {NES = 1, SNES, GENESIS, GBGG};
enum Errors {INVALID_LENGTH, MEMORY_ERROR, NO_FREE_MEMORY, INVALID_CODE};

extern const char *errors[];
extern const char *titles[];
extern const char *ggstr;

/* ggdecode.c prototypes */

void strupr(char *);
unsigned short int convertHexDec(const char);
unsigned long int toDecimal(const char *, short int);
void _main(void);

#ifdef _NES_SUPPORT_
/* nes.c prototypes */
char decodeNEStoHex(const char);
short int isValidNES(char *, short int);
void decodeNES6(unsigned long int, unsigned short int *, unsigned short int *);
void decodeNES8(unsigned long int, unsigned short int *, unsigned short int *,unsigned short int *);
void convertNES(char *);
#endif

#ifdef _SNES_SUPPORT_
/* snes.c prototypes */
char decodeSNEStoHex(const char);
short int isValidSNES(unsigned char *, short int *);
void decodeSNES(unsigned long int, unsigned short int *, unsigned long int *);
void convertSNES(char *);
#endif

#ifdef _GENESIS_SUPPORT_
/* genesis.c prototypes */
short int decodeGenesisToHex(const char);
short int isValidGenesis(unsigned char *, short int *, char *);
void decodeGenesis(const char *, char *, char *);
void convertGenesis(char *);
#endif

#ifdef _GBGG_SUPPORT_
/* gbgg.c prototypes */
short int isValidHex(const char);
short int isValidGBGG(unsigned char *, short int *);
void decodeGBGG(const char *, char *, char *, char *, short int);
void convertGBGG(char *);
#endif

#endif
